@@ -1,12 +1,12 @@
-/* 
+/*
  * Gnome Chemistry Utils
- * object.cc 
+ * object.cc
  *
- * Copyright (C) 2002-2010 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2002-2011 Jean Bréfort <jean.brefort@normalesup.org>
  *
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of the GNU General Public License as 
- * published by the Free Software Foundation; either version 2 of the
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; either version 3 of the
  * License, or (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -26,6 +26,7 @@
 #include "application.h"
 #include "dialog.h"
 #include "document.h"
+#include "ui-manager.h"
 #include <glib/gi18n.h>
 #include <string>
 #include <iostream>
@@ -232,8 +233,6 @@ Object* Object::GetDescendant (const gchar* Id) const
 	string sId = pDoc->GetTranslatedId (Id);
 	if (sId.size ())
 		Id = sId.c_str ();
-	else
-		pDoc->EraseTranslationId (Id);
 	return RealGetDescendant (Id);
 }
 
@@ -267,7 +266,7 @@ Object const *Object::GetFirstChild (map<string, Object*>::const_iterator& i) co
 		return NULL;
 	return (*i).second;
 }
-	
+
 Object *Object::GetNextChild (map<string, Object*>::iterator& i)
 {
 	i++;
@@ -275,7 +274,7 @@ Object *Object::GetNextChild (map<string, Object*>::iterator& i)
 		return NULL;
 	return (*i).second;
 }
-	
+
 Object const *Object::GetNextChild (map<string, Object*>::const_iterator& i) const
 {
 	i++;
@@ -291,7 +290,7 @@ xmlNodePtr Object::Save (xmlDocPtr xml) const
 	if (!node)
 		return NULL;
 	SaveId (node);
-	
+
 	if (!SaveChildren (xml, node)) {
 		xmlFreeNode (node);
 		return NULL;
@@ -326,8 +325,21 @@ bool Object::Load (xmlNodePtr node)
 		node = (strcmp ((const char*) child->name, "object"))? child: child->children;
 		pObject = CreateObject ((const char*) node->name, this);
 		if (pObject) {
-			if (!pObject->Load (node))
+			if (!pObject->Load (node)) {
 				delete pObject;
+				if (node != child) {
+					for (node = node->next; node; node = node->next) {
+						pObject = CreateObject ((const char*) node->name, this);
+						if (pObject) {
+							if (!pObject->Load (node))
+								delete pObject;
+						} else {
+							m_Locked--;
+							return false;
+						}
+					}
+				}
+			}
 		} else {
 			m_Locked--;
 			return false;
@@ -400,11 +412,11 @@ void Object::Transform2D(Matrix2D& m, double x, double y)
 		(*i).second->Transform2D (m, x, y);
 }
 
-bool Object::BuildContextualMenu (GtkUIManager *UIManager, Object *object, double x, double y)
+bool Object::BuildContextualMenu (UIManager *uim, Object *object, double x, double y)
 {
 	Application *app = GetApplication ();
-	bool result = (app)? app->BuildObjectContextualMenu (this, UIManager, object, x, y): false;
-	return result | ((m_Parent)? m_Parent->BuildContextualMenu (UIManager, object, x, y): false);
+	bool result = (app)? app->BuildObjectContextualMenu (this, uim, object, x, y): false;
+	return result | ((m_Parent)? m_Parent->BuildContextualMenu (uim, object, x, y): false);
 }
 
 char const *Object::HasPropertiesDialog () const
@@ -430,7 +442,7 @@ void Object::ShowPropertiesDialog ()
 		dlg = BuildPropertiesDialog ();
 	if (dlg)
 		dlg->Present ();
-	
+
 }
 
 Object* Object::GetAtomAt (G_GNUC_UNUSED double x, G_GNUC_UNUSED double y, G_GNUC_UNUSED double z)
@@ -438,7 +450,7 @@ Object* Object::GetAtomAt (G_GNUC_UNUSED double x, G_GNUC_UNUSED double y, G_GNU
 	return NULL;
 }
 
-bool Object::Build (G_GNUC_UNUSED list<Object*>& Children) throw (invalid_argument)
+bool Object::Build (G_GNUC_UNUSED std::set < Object * > const &Children) throw (invalid_argument)
 {
 	return false;
 }
